@@ -25,7 +25,9 @@ __all__ = (
     "DescribeLoadBalancersPaginatorName",
     "InstanceDeregisteredWaiterName",
     "InstanceInServiceWaiterName",
+    "ElasticLoadBalancingServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
 )
@@ -36,6 +38,7 @@ DescribeAccountLimitsPaginatorName = Literal["describe_account_limits"]
 DescribeLoadBalancersPaginatorName = Literal["describe_load_balancers"]
 InstanceDeregisteredWaiterName = Literal["instance_deregistered"]
 InstanceInServiceWaiterName = Literal["instance_in_service"]
+ElasticLoadBalancingServiceName = Literal["elb"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -67,6 +70,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -189,6 +193,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -337,5 +342,17 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["describe_account_limits", "describe_load_balancers"]
 WaiterName = Literal["any_instance_in_service", "instance_deregistered", "instance_in_service"]
