@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence
 
+from typing_extensions import NotRequired
+
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -99,26 +101,15 @@ __all__ = (
     "WaiterConfigTypeDef",
 )
 
-_RequiredAccessLogTypeDef = TypedDict(
-    "_RequiredAccessLogTypeDef",
+AccessLogTypeDef = TypedDict(
+    "AccessLogTypeDef",
     {
         "Enabled": bool,
+        "S3BucketName": NotRequired[str],
+        "EmitInterval": NotRequired[int],
+        "S3BucketPrefix": NotRequired[str],
     },
 )
-_OptionalAccessLogTypeDef = TypedDict(
-    "_OptionalAccessLogTypeDef",
-    {
-        "S3BucketName": str,
-        "EmitInterval": int,
-        "S3BucketPrefix": str,
-    },
-    total=False,
-)
-
-
-class AccessLogTypeDef(_RequiredAccessLogTypeDef, _OptionalAccessLogTypeDef):
-    pass
-
 
 AddAvailabilityZonesInputRequestTypeDef = TypedDict(
     "AddAvailabilityZonesInputRequestTypeDef",
@@ -147,19 +138,17 @@ AddTagsInputRequestTypeDef = TypedDict(
 AdditionalAttributeTypeDef = TypedDict(
     "AdditionalAttributeTypeDef",
     {
-        "Key": str,
-        "Value": str,
+        "Key": NotRequired[str],
+        "Value": NotRequired[str],
     },
-    total=False,
 )
 
 AppCookieStickinessPolicyTypeDef = TypedDict(
     "AppCookieStickinessPolicyTypeDef",
     {
-        "PolicyName": str,
-        "CookieName": str,
+        "PolicyName": NotRequired[str],
+        "CookieName": NotRequired[str],
     },
-    total=False,
 )
 
 ApplySecurityGroupsToLoadBalancerInputRequestTypeDef = TypedDict(
@@ -197,10 +186,9 @@ AttachLoadBalancerToSubnetsOutputTypeDef = TypedDict(
 BackendServerDescriptionTypeDef = TypedDict(
     "BackendServerDescriptionTypeDef",
     {
-        "InstancePort": int,
-        "PolicyNames": List[str],
+        "InstancePort": NotRequired[int],
+        "PolicyNames": NotRequired[List[str]],
     },
-    total=False,
 )
 
 ConfigureHealthCheckInputRequestTypeDef = TypedDict(
@@ -219,26 +207,13 @@ ConfigureHealthCheckOutputTypeDef = TypedDict(
     },
 )
 
-_RequiredConnectionDrainingTypeDef = TypedDict(
-    "_RequiredConnectionDrainingTypeDef",
+ConnectionDrainingTypeDef = TypedDict(
+    "ConnectionDrainingTypeDef",
     {
         "Enabled": bool,
+        "Timeout": NotRequired[int],
     },
 )
-_OptionalConnectionDrainingTypeDef = TypedDict(
-    "_OptionalConnectionDrainingTypeDef",
-    {
-        "Timeout": int,
-    },
-    total=False,
-)
-
-
-class ConnectionDrainingTypeDef(
-    _RequiredConnectionDrainingTypeDef, _OptionalConnectionDrainingTypeDef
-):
-    pass
-
 
 ConnectionSettingsTypeDef = TypedDict(
     "ConnectionSettingsTypeDef",
@@ -247,31 +222,18 @@ ConnectionSettingsTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateAccessPointInputRequestTypeDef = TypedDict(
-    "_RequiredCreateAccessPointInputRequestTypeDef",
+CreateAccessPointInputRequestTypeDef = TypedDict(
+    "CreateAccessPointInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "Listeners": Sequence["ListenerTypeDef"],
+        "AvailabilityZones": NotRequired[Sequence[str]],
+        "Subnets": NotRequired[Sequence[str]],
+        "SecurityGroups": NotRequired[Sequence[str]],
+        "Scheme": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreateAccessPointInputRequestTypeDef = TypedDict(
-    "_OptionalCreateAccessPointInputRequestTypeDef",
-    {
-        "AvailabilityZones": Sequence[str],
-        "Subnets": Sequence[str],
-        "SecurityGroups": Sequence[str],
-        "Scheme": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateAccessPointInputRequestTypeDef(
-    _RequiredCreateAccessPointInputRequestTypeDef, _OptionalCreateAccessPointInputRequestTypeDef
-):
-    pass
-
 
 CreateAccessPointOutputTypeDef = TypedDict(
     "CreateAccessPointOutputTypeDef",
@@ -290,28 +252,14 @@ CreateAppCookieStickinessPolicyInputRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateLBCookieStickinessPolicyInputRequestTypeDef = TypedDict(
-    "_RequiredCreateLBCookieStickinessPolicyInputRequestTypeDef",
+CreateLBCookieStickinessPolicyInputRequestTypeDef = TypedDict(
+    "CreateLBCookieStickinessPolicyInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "PolicyName": str,
+        "CookieExpirationPeriod": NotRequired[int],
     },
 )
-_OptionalCreateLBCookieStickinessPolicyInputRequestTypeDef = TypedDict(
-    "_OptionalCreateLBCookieStickinessPolicyInputRequestTypeDef",
-    {
-        "CookieExpirationPeriod": int,
-    },
-    total=False,
-)
-
-
-class CreateLBCookieStickinessPolicyInputRequestTypeDef(
-    _RequiredCreateLBCookieStickinessPolicyInputRequestTypeDef,
-    _OptionalCreateLBCookieStickinessPolicyInputRequestTypeDef,
-):
-    pass
-
 
 CreateLoadBalancerListenerInputRequestTypeDef = TypedDict(
     "CreateLoadBalancerListenerInputRequestTypeDef",
@@ -321,29 +269,15 @@ CreateLoadBalancerListenerInputRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
-    "_RequiredCreateLoadBalancerPolicyInputRequestTypeDef",
+CreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
+    "CreateLoadBalancerPolicyInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "PolicyName": str,
         "PolicyTypeName": str,
+        "PolicyAttributes": NotRequired[Sequence["PolicyAttributeTypeDef"]],
     },
 )
-_OptionalCreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
-    "_OptionalCreateLoadBalancerPolicyInputRequestTypeDef",
-    {
-        "PolicyAttributes": Sequence["PolicyAttributeTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateLoadBalancerPolicyInputRequestTypeDef(
-    _RequiredCreateLoadBalancerPolicyInputRequestTypeDef,
-    _OptionalCreateLoadBalancerPolicyInputRequestTypeDef,
-):
-    pass
-
 
 CrossZoneLoadBalancingTypeDef = TypedDict(
     "CrossZoneLoadBalancingTypeDef",
@@ -394,11 +328,10 @@ DeregisterEndPointsOutputTypeDef = TypedDict(
 DescribeAccessPointsInputRequestTypeDef = TypedDict(
     "DescribeAccessPointsInputRequestTypeDef",
     {
-        "LoadBalancerNames": Sequence[str],
-        "Marker": str,
-        "PageSize": int,
+        "LoadBalancerNames": NotRequired[Sequence[str]],
+        "Marker": NotRequired[str],
+        "PageSize": NotRequired[int],
     },
-    total=False,
 )
 
 DescribeAccessPointsOutputTypeDef = TypedDict(
@@ -413,10 +346,9 @@ DescribeAccessPointsOutputTypeDef = TypedDict(
 DescribeAccountLimitsInputRequestTypeDef = TypedDict(
     "DescribeAccountLimitsInputRequestTypeDef",
     {
-        "Marker": str,
-        "PageSize": int,
+        "Marker": NotRequired[str],
+        "PageSize": NotRequired[int],
     },
-    total=False,
 )
 
 DescribeAccountLimitsOutputTypeDef = TypedDict(
@@ -428,27 +360,13 @@ DescribeAccountLimitsOutputTypeDef = TypedDict(
     },
 )
 
-_RequiredDescribeEndPointStateInputRequestTypeDef = TypedDict(
-    "_RequiredDescribeEndPointStateInputRequestTypeDef",
+DescribeEndPointStateInputRequestTypeDef = TypedDict(
+    "DescribeEndPointStateInputRequestTypeDef",
     {
         "LoadBalancerName": str,
+        "Instances": NotRequired[Sequence["InstanceTypeDef"]],
     },
 )
-_OptionalDescribeEndPointStateInputRequestTypeDef = TypedDict(
-    "_OptionalDescribeEndPointStateInputRequestTypeDef",
-    {
-        "Instances": Sequence["InstanceTypeDef"],
-    },
-    total=False,
-)
-
-
-class DescribeEndPointStateInputRequestTypeDef(
-    _RequiredDescribeEndPointStateInputRequestTypeDef,
-    _OptionalDescribeEndPointStateInputRequestTypeDef,
-):
-    pass
-
 
 DescribeEndPointStateOutputTypeDef = TypedDict(
     "DescribeEndPointStateOutputTypeDef",
@@ -476,10 +394,9 @@ DescribeLoadBalancerAttributesOutputTypeDef = TypedDict(
 DescribeLoadBalancerPoliciesInputRequestTypeDef = TypedDict(
     "DescribeLoadBalancerPoliciesInputRequestTypeDef",
     {
-        "LoadBalancerName": str,
-        "PolicyNames": Sequence[str],
+        "LoadBalancerName": NotRequired[str],
+        "PolicyNames": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 DescribeLoadBalancerPoliciesOutputTypeDef = TypedDict(
@@ -493,9 +410,8 @@ DescribeLoadBalancerPoliciesOutputTypeDef = TypedDict(
 DescribeLoadBalancerPolicyTypesInputRequestTypeDef = TypedDict(
     "DescribeLoadBalancerPolicyTypesInputRequestTypeDef",
     {
-        "PolicyTypeNames": Sequence[str],
+        "PolicyTypeNames": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 DescribeLoadBalancerPolicyTypesOutputTypeDef = TypedDict(
@@ -551,104 +467,86 @@ HealthCheckTypeDef = TypedDict(
 InstanceStateTypeDef = TypedDict(
     "InstanceStateTypeDef",
     {
-        "InstanceId": str,
-        "State": str,
-        "ReasonCode": str,
-        "Description": str,
+        "InstanceId": NotRequired[str],
+        "State": NotRequired[str],
+        "ReasonCode": NotRequired[str],
+        "Description": NotRequired[str],
     },
-    total=False,
 )
 
 InstanceTypeDef = TypedDict(
     "InstanceTypeDef",
     {
-        "InstanceId": str,
+        "InstanceId": NotRequired[str],
     },
-    total=False,
 )
 
 LBCookieStickinessPolicyTypeDef = TypedDict(
     "LBCookieStickinessPolicyTypeDef",
     {
-        "PolicyName": str,
-        "CookieExpirationPeriod": int,
+        "PolicyName": NotRequired[str],
+        "CookieExpirationPeriod": NotRequired[int],
     },
-    total=False,
 )
 
 LimitTypeDef = TypedDict(
     "LimitTypeDef",
     {
-        "Name": str,
-        "Max": str,
+        "Name": NotRequired[str],
+        "Max": NotRequired[str],
     },
-    total=False,
 )
 
 ListenerDescriptionTypeDef = TypedDict(
     "ListenerDescriptionTypeDef",
     {
-        "Listener": "ListenerTypeDef",
-        "PolicyNames": List[str],
+        "Listener": NotRequired["ListenerTypeDef"],
+        "PolicyNames": NotRequired[List[str]],
     },
-    total=False,
 )
 
-_RequiredListenerTypeDef = TypedDict(
-    "_RequiredListenerTypeDef",
+ListenerTypeDef = TypedDict(
+    "ListenerTypeDef",
     {
         "Protocol": str,
         "LoadBalancerPort": int,
         "InstancePort": int,
+        "InstanceProtocol": NotRequired[str],
+        "SSLCertificateId": NotRequired[str],
     },
 )
-_OptionalListenerTypeDef = TypedDict(
-    "_OptionalListenerTypeDef",
-    {
-        "InstanceProtocol": str,
-        "SSLCertificateId": str,
-    },
-    total=False,
-)
-
-
-class ListenerTypeDef(_RequiredListenerTypeDef, _OptionalListenerTypeDef):
-    pass
-
 
 LoadBalancerAttributesTypeDef = TypedDict(
     "LoadBalancerAttributesTypeDef",
     {
-        "CrossZoneLoadBalancing": "CrossZoneLoadBalancingTypeDef",
-        "AccessLog": "AccessLogTypeDef",
-        "ConnectionDraining": "ConnectionDrainingTypeDef",
-        "ConnectionSettings": "ConnectionSettingsTypeDef",
-        "AdditionalAttributes": List["AdditionalAttributeTypeDef"],
+        "CrossZoneLoadBalancing": NotRequired["CrossZoneLoadBalancingTypeDef"],
+        "AccessLog": NotRequired["AccessLogTypeDef"],
+        "ConnectionDraining": NotRequired["ConnectionDrainingTypeDef"],
+        "ConnectionSettings": NotRequired["ConnectionSettingsTypeDef"],
+        "AdditionalAttributes": NotRequired[List["AdditionalAttributeTypeDef"]],
     },
-    total=False,
 )
 
 LoadBalancerDescriptionTypeDef = TypedDict(
     "LoadBalancerDescriptionTypeDef",
     {
-        "LoadBalancerName": str,
-        "DNSName": str,
-        "CanonicalHostedZoneName": str,
-        "CanonicalHostedZoneNameID": str,
-        "ListenerDescriptions": List["ListenerDescriptionTypeDef"],
-        "Policies": "PoliciesTypeDef",
-        "BackendServerDescriptions": List["BackendServerDescriptionTypeDef"],
-        "AvailabilityZones": List[str],
-        "Subnets": List[str],
-        "VPCId": str,
-        "Instances": List["InstanceTypeDef"],
-        "HealthCheck": "HealthCheckTypeDef",
-        "SourceSecurityGroup": "SourceSecurityGroupTypeDef",
-        "SecurityGroups": List[str],
-        "CreatedTime": datetime,
-        "Scheme": str,
+        "LoadBalancerName": NotRequired[str],
+        "DNSName": NotRequired[str],
+        "CanonicalHostedZoneName": NotRequired[str],
+        "CanonicalHostedZoneNameID": NotRequired[str],
+        "ListenerDescriptions": NotRequired[List["ListenerDescriptionTypeDef"]],
+        "Policies": NotRequired["PoliciesTypeDef"],
+        "BackendServerDescriptions": NotRequired[List["BackendServerDescriptionTypeDef"]],
+        "AvailabilityZones": NotRequired[List[str]],
+        "Subnets": NotRequired[List[str]],
+        "VPCId": NotRequired[str],
+        "Instances": NotRequired[List["InstanceTypeDef"]],
+        "HealthCheck": NotRequired["HealthCheckTypeDef"],
+        "SourceSecurityGroup": NotRequired["SourceSecurityGroupTypeDef"],
+        "SecurityGroups": NotRequired[List[str]],
+        "CreatedTime": NotRequired[datetime],
+        "Scheme": NotRequired[str],
     },
-    total=False,
 )
 
 ModifyLoadBalancerAttributesInputRequestTypeDef = TypedDict(
@@ -671,71 +569,66 @@ ModifyLoadBalancerAttributesOutputTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 PoliciesTypeDef = TypedDict(
     "PoliciesTypeDef",
     {
-        "AppCookieStickinessPolicies": List["AppCookieStickinessPolicyTypeDef"],
-        "LBCookieStickinessPolicies": List["LBCookieStickinessPolicyTypeDef"],
-        "OtherPolicies": List[str],
+        "AppCookieStickinessPolicies": NotRequired[List["AppCookieStickinessPolicyTypeDef"]],
+        "LBCookieStickinessPolicies": NotRequired[List["LBCookieStickinessPolicyTypeDef"]],
+        "OtherPolicies": NotRequired[List[str]],
     },
-    total=False,
 )
 
 PolicyAttributeDescriptionTypeDef = TypedDict(
     "PolicyAttributeDescriptionTypeDef",
     {
-        "AttributeName": str,
-        "AttributeValue": str,
+        "AttributeName": NotRequired[str],
+        "AttributeValue": NotRequired[str],
     },
-    total=False,
 )
 
 PolicyAttributeTypeDef = TypedDict(
     "PolicyAttributeTypeDef",
     {
-        "AttributeName": str,
-        "AttributeValue": str,
+        "AttributeName": NotRequired[str],
+        "AttributeValue": NotRequired[str],
     },
-    total=False,
 )
 
 PolicyAttributeTypeDescriptionTypeDef = TypedDict(
     "PolicyAttributeTypeDescriptionTypeDef",
     {
-        "AttributeName": str,
-        "AttributeType": str,
-        "Description": str,
-        "DefaultValue": str,
-        "Cardinality": str,
+        "AttributeName": NotRequired[str],
+        "AttributeType": NotRequired[str],
+        "Description": NotRequired[str],
+        "DefaultValue": NotRequired[str],
+        "Cardinality": NotRequired[str],
     },
-    total=False,
 )
 
 PolicyDescriptionTypeDef = TypedDict(
     "PolicyDescriptionTypeDef",
     {
-        "PolicyName": str,
-        "PolicyTypeName": str,
-        "PolicyAttributeDescriptions": List["PolicyAttributeDescriptionTypeDef"],
+        "PolicyName": NotRequired[str],
+        "PolicyTypeName": NotRequired[str],
+        "PolicyAttributeDescriptions": NotRequired[List["PolicyAttributeDescriptionTypeDef"]],
     },
-    total=False,
 )
 
 PolicyTypeDescriptionTypeDef = TypedDict(
     "PolicyTypeDescriptionTypeDef",
     {
-        "PolicyTypeName": str,
-        "Description": str,
-        "PolicyAttributeTypeDescriptions": List["PolicyAttributeTypeDescriptionTypeDef"],
+        "PolicyTypeName": NotRequired[str],
+        "Description": NotRequired[str],
+        "PolicyAttributeTypeDescriptions": NotRequired[
+            List["PolicyAttributeTypeDescriptionTypeDef"]
+        ],
     },
-    total=False,
 )
 
 RegisterEndPointsInputRequestTypeDef = TypedDict(
@@ -819,53 +712,38 @@ SetLoadBalancerPoliciesOfListenerInputRequestTypeDef = TypedDict(
 SourceSecurityGroupTypeDef = TypedDict(
     "SourceSecurityGroupTypeDef",
     {
-        "OwnerAlias": str,
-        "GroupName": str,
+        "OwnerAlias": NotRequired[str],
+        "GroupName": NotRequired[str],
     },
-    total=False,
 )
 
 TagDescriptionTypeDef = TypedDict(
     "TagDescriptionTypeDef",
     {
-        "LoadBalancerName": str,
-        "Tags": List["TagTypeDef"],
+        "LoadBalancerName": NotRequired[str],
+        "Tags": NotRequired[List["TagTypeDef"]],
     },
-    total=False,
 )
 
 TagKeyOnlyTypeDef = TypedDict(
     "TagKeyOnlyTypeDef",
     {
-        "Key": str,
+        "Key": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredTagTypeDef = TypedDict(
-    "_RequiredTagTypeDef",
+TagTypeDef = TypedDict(
+    "TagTypeDef",
     {
         "Key": str,
+        "Value": NotRequired[str],
     },
 )
-_OptionalTagTypeDef = TypedDict(
-    "_OptionalTagTypeDef",
-    {
-        "Value": str,
-    },
-    total=False,
-)
-
-
-class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
-    pass
-
 
 WaiterConfigTypeDef = TypedDict(
     "WaiterConfigTypeDef",
     {
-        "Delay": int,
-        "MaxAttempts": int,
+        "Delay": NotRequired[int],
+        "MaxAttempts": NotRequired[int],
     },
-    total=False,
 )
